@@ -2,7 +2,7 @@ import functools
 from django.db import transaction
 from rest_framework import status
 from .methods import get_response
-    
+from rest_framework.exceptions import APIException
 
 def exceptions_endpoint(atomic: bool=True):    
     def wrapper(endpoint):
@@ -14,6 +14,9 @@ def exceptions_endpoint(atomic: bool=True):
                         return endpoint(request, *args, **kwargs)
                 return endpoint(request, *args, **kwargs)
             except Exception as e:
-                    return get_response(str(e), status.HTTP_400_BAD_REQUEST)
+                status_code = status.HTTP_400_BAD_REQUEST
+                if isinstance(e, APIException):
+                    status_code = e.status_code
+                return get_response(str(e), status_code)
         return inner
     return wrapper
\ No newline at end of file
